==> amarok-2.4.3.tar.bz2: amarok-2.4.3/src/core-impl/collections/db/sql/SqlCollectionFactory.cpp <==
/****************************************************************************************
 * Copyright (c) 2009 Maximilian Kossick <maximilian.kossick@googlemail.com>            *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "SqlCollectionFactory.h"

#include "SqlCollection.h"
#include "MountPointManager.h"

#include <KLocale>

Collections::SqlCollectionFactory::SqlCollectionFactory()
{
}

Collections::SqlCollection*
Collections::SqlCollectionFactory::createSqlCollection( const QString &id, const QString &prettyName, SqlStorage *storage ) const
{
    SqlCollection *coll = new SqlCollection( id, prettyName, storage );

    MountPointManager *mpm = new MountPointManager( coll, storage );

    coll->setMountPointManager( mpm );

    //everything has been set up
    coll->init();
    return coll;
}

==> amarok-2.7.0.tar.bz2: amarok-2.7.0/src/core-impl/collections/db/sql/SqlCollectionFactory.cpp <==
/****************************************************************************************
 * Copyright (c) 2009 Maximilian Kossick <maximilian.kossick@googlemail.com>            *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "SqlCollectionFactory.h"

#include "core-impl/collections/db/MountPointManager.h"
#include "core-impl/collections/db/sql/SqlCollection.h"

#include <KLocale>

Collections::SqlCollectionFactory::SqlCollectionFactory()
{
}

Collections::SqlCollection*
Collections::SqlCollectionFactory::createSqlCollection( const QString &id,
                                                        const QString &prettyName,
                                                        SqlStorage *storage ) const
{
    SqlCollection *coll = new SqlCollection( id, prettyName, storage );
    MountPointManager *mpm = new MountPointManager( coll, storage );
    coll->setMountPointManager( mpm );
    return coll;
}
